@@ -8,9 +8,9 @@ use Log::ger;
 use Exporter 'import';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-03-16'; # DATE
+our $DATE = '2023-03-30'; # DATE
 our $DIST = 'App-BPOMUtils-RPO-Checker'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our @EXPORT_OK = qw(
                        bpom_rpo_check_label_files_design
@@ -20,7 +20,7 @@ our %SPEC;
 
 our %argspec0plus_filenames = (
     filenames => {
-        schema => ['array*', of=>'filename', 'x.perl.default_value_rules' => [['Path::filenames'=>{recursive=>1}]]],
+        schema => ['array*', of=>'filename', 'x.perl.default_value_rules' => [['Path::filenames'=>{recurse=>1}]]],
         pos => 0,
         slurpy => 1,
     },
@@ -230,7 +230,7 @@ App::BPOMUtils::RPO::Checker - Various checker utilities to help with Processed
 
 =head1 VERSION
 
-This document describes version 0.011 of App::BPOMUtils::RPO::Checker (from Perl distribution App-BPOMUtils-RPO-Checker), released on 2023-03-16.
+This document describes version 0.012 of App::BPOMUtils::RPO::Checker (from Perl distribution App-BPOMUtils-RPO-Checker), released on 2023-03-30.
 
 =head1 SYNOPSIS
 
